#
# spec file for package gearlever
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define appid it.mijorus.gearlever
Name:           gearlever
Version:        3.3.4
Release:        1.1
Summary:        Manage AppImages
License:        GPL-3.0-or-later
URL:            https://gearlever.mijorus.it/
Source:         https://github.com/mijorus/gearlever/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Group:          System/X11/Utilities
BuildArch:      noarch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  gtk4-tools
BuildRequires:  meson
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0)
Requires:       7zip
Requires:       dwarfs
Requires:       flatpak-spawn
Requires:       python3-dbus-python
Requires:       python3-pyxdg
Requires:       squashfs

%description
An utility to manage AppImages with ease! Gear lever will organize and manage
AppImage files for you, generate desktop entries and app metadata, update apps
in-place or keep multiple versions side-by-side.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %name --all-name
%suse_update_desktop_file %{appid}
%fdupes %{buildroot}/%{_prefix}
rm %{buildroot}/%{_datadir}/gearlever/gearlever/assets/demo.AppImage
find %{buildroot} -iname 'meson.build' -delete

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{appid}.appdata.xml
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/scalable/actions
%{_datadir}/icons/hicolor/*/apps/%{appid}*.svg

%files lang -f %{name}.lang

%changelog
* Tue Jul 15 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.3.4:
  * Fixed an issue caused by apps with spaces in their file names
- Update to 3.3.3:
  * Fixed an issue introduced with 3.3.1
  * Fixed an issue causing some apps to be detected as always out-of-date
- Update to 3.3.1:
  * Fixed an issue causing app updates to delete the original app
- Update to 3.3.0:
  * Added support for Gitlab
  * Added support for Codeberg
  * Allow users to override the update url provided by the developer
* Fri May  9 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.2.4:
  * added x-appimage as supported mime
- Update to 3.2.3:
  * unsquashfs: fixed errors with symbolic links
* Mon Apr 21 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.2.2:
  * Improved support for apps using squashfs
* Wed Apr 16 2025 Son <vincent.son.ziwen@outlook.com>
- Update to 3.2.1
  * New feature: "Update all", for both the CLI and UI
  * Fixed some issues for apps using dwarfs filesystem
* Sat Apr 12 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.1.1:
  * Added searchbar icon
- Update to 3.1.0:
  * Added support for AppImages using dwarfs filesystem
* Wed Mar 26 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 3.0.2:
  * Fixed an issue causing the "Keep both" option to override the old desktop
    file
- Update to 3.0.1:
  * Fixed an issue causing custom Github update urls being ignored when
    checking for updates
- Update to 3.0.0:
  * Gear Lever now has a brand new command-line interface for managing and
    updating apps
* Sat Jan 18 2025 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.3.2:
  * ignore get_osinfo output if it fails
  * Add finnish translation
* Thu Nov 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.3.0:
  * Added a confirmation modal when removing an app
- Update to 2.2.1:
  * Fixed an issue causing update errors for some apps
- Update to 2.2.0:
  * Added checks to download the correct AppImage for the current system architecture
- Update to 2.1.0:
  * Added an option to fetch updates in the background at system startup
* Mon Sep 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.0.7:
  * Fixed incorrect url detection for some links
- Update to 2.0.6:
  * Updated appimage type detection according to the specs
  * Moved the "Cancel download" button to avoid unintentional errors
- Update to 2.0.5:
  * Added checks to detect if Gear Lever is running as a flatpak
  * Bug fix
* Sat Aug  3 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.0.4
  * Improved checking for static update url
  * Do not append md5 hashes to filenames anymore
- Update to 2.0.3
  * Added support for apps that do not specify icons in their desktop file
- Update to 2.0.1
  * Accept globe characters in the release names of custom Github update links
  * Fixed an issue causing crashes on systems that do not support gtk-launch
  * Fixed an issue causing crashes when attempting to open apps with non-ascii characters in their names
  * Fixed an issue causing some appimages to be considered invalid because of the lack of an AppRun file
- Update to 2.0.0
  * Gear Lever can now fetch updates from embedded or custom sources and update your apps automaticallyo
- Update to 1.6.5
  * Improved support for NixOS
- Update to 1.6.4
  * Fixed an issue causing the app to crash if the "strings" util is not available
- Update to 1.6.3
  * Keep environment variables when updating an app with the "Replace" option
  * Fixed an issue causing app to override themself when updating with "Keep" option
- Update to 1.6.2
  * Fixed bugs introduced with 1.6.1 causing the app to crash at startup
  * Fixed an issue causing multi-install to fail
- Update to 1.6.1
  * Added Appimage Type 3 detection
  * Added error warning when libfuse is missing on the host system
* Tue Jun  4 2024 Rodrigo Pedra Brum <rodrigo.pedra@gmail.com>
- Update to 1.6.0
  * Improved app analysis performance
  * Improved debug logs
  * Fixed some issues with special characters in filenames
- Drop 0001-Rename-icon-with-generic-name-that-conflicts-with-an.patch
* Fri May 10 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Rename-icon-with-generic-name-that-conflicts-with-an.patch
* Tue May  7 2024 Rodrigo Pedra Brum <rodrigo.pedra@gmail.com>
- Update to 1.5.2
* Mon Dec 11 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.0.18
- Drop 0001-Don-t-install-the-file-gearlever.in.patch
* Mon Dec  4 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Don-t-install-the-file-gearlever.in.patch
* Wed Nov 22 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Initial package
